<?php

namespace MetodikaTI\Http\Controllers\Back;

use Auth;
use Carbon\Carbon;
use Illuminate\Contracts\Auth\Guard;
use Illuminate\Contracts\Auth\PasswordBroker;
use Illuminate\Foundation\Auth\ResetsPasswords;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Crypt;
use MetodikaTI\Http\Controllers\Controller;
use MetodikaTI\Http\Requests\Back\Account\LoginRequest;
use MetodikaTI\Http\Requests\Back\Account\ResetPasswordRequest;
use MetodikaTI\Library\Pastora;
use MetodikaTI\PasswordReset;
use MetodikaTI\PasswordResets;
use MetodikaTI\User;
use MetodikaTI\Institution;
use Session;
use Illuminate\Support\Facades\Mail;
// use App\Mail\TestMail;



class AccountController extends Controller
{
    use ResetsPasswords;
    protected $tokens;


    public function __construct(Guard $auth, PasswordBroker $passwords)
    {
        $this->auth = $auth;
        $this->passwords = $passwords;
        $this->subject = 'Recuperación de contraseña';
    }


    public function getHome()
    {
        return view('back.account.home');
    }


    public function postLogin(LoginRequest $request)
    {

        $credentials = [
            'email' => $request->email,
            'password' => $request->password
        ];

        $token = $_POST["g-recaptcha-response"];
        $verificado = $this->verificarToken($token, env("KEY_SECRET_reCAPTCHA"));


        if( !$token ){
            Session::flash('loginError', true);
            Session::flash('loginMsg', 'El reCAPTCHA es requerido');
            return redirect()->intended('');
        }else{
            if( $verificado ){

                $usuario = User::where("email", $request->email)->first();                

                if( empty( $usuario ) ){
                    Session::flash('loginError', true);
                    Session::flash('lastEmail', $request->email);
                    Session::flash('loginMsg', 'Cuenta de correo y/o contraseña incorrectos.');
                    return redirect()->intended('');
                }

                if( $usuario->id_institucion !== 0 ){

                    $institucion = Institution::find($usuario->id_institucion);
    
                    if( $institucion->estatus == 0 ){
                        Session::flash('loginError', true);
                        Session::flash('loginMsg', 'La institución se encuentra inactiva');
                        return redirect()->intended('');
                    }

                }

                if (Auth::attempt($credentials)) {

                    return redirect()->intended('dashboard');
        
                } else {
                    Session::flash('loginError', true);
                    Session::flash('lastEmail', $request->email);
                    Session::flash('loginMsg', 'Cuenta de correo y/o contraseña incorrectos.');
                    return redirect()->intended('');
                }

            }else{
                Session::flash('loginError', true);
                Session::flash('loginMsg', 'El reCAPTCHA no pudo ser comprobado');
                return redirect()->intended('');
            }
        }


        // if (Auth::attempt($credentials)) {

        //     return redirect()->intended('dashboard');

        // } else {
        //     Session::flash('loginError', true);
        //     Session::flash('lastEmail', $request->email);
        //     Session::flash('loginMsg', 'Cuenta de correo y/o contraseña incorrectos.');
        //     return redirect()->intended('');
        // }

    }

    private function verificarToken($token, $claveSecreta)
    {
        # La API en donde verificamos el token
        $url = "https://www.google.com/recaptcha/api/siteverify";
        # Los datos que enviamos a Google
        $datos = [
            "secret" => $claveSecreta,
            "response" => $token,
        ];
        // Crear opciones de la petición HTTP
        $opciones = array(
            "http" => array(
                "header" => "Content-type: application/x-www-form-urlencoded\r\n",
                "method" => "POST",
                "content" => http_build_query($datos), # Agregar el contenido definido antes
            ),
        );
        # Preparar petición
        $contexto = stream_context_create($opciones);
        # Hacerla
        $resultado = file_get_contents($url, false, $contexto);
        # Si hay problemas con la petición (por ejemplo, que no hay internet o algo así)
        # entonces se regresa false. Este NO es un problema con el captcha, sino con la conexión
        # al servidor de Google
        if ($resultado === false) {
            # Error haciendo petición
            return false;
        }
    
        # En caso de que no haya regresado false, decodificamos con JSON
    
        $resultado = json_decode($resultado);
        # La variable que nos interesa para saber si el usuario pasó o no la prueba
        # está en success
        $pruebaPasada = $resultado->success;
        # Regresamos ese valor, y listo (sí, ya sé que se podría regresar $resultado->success)
        return $pruebaPasada;
    }


    protected function guard()
    {
        return Auth::guard('clients');
    }


    public function getLogout()
    {
        Auth::logout();

        return redirect("");
    }


    public function getRecovery()
    {
        return view('back.account.recovery');
    }


    public function postReset(Request $request)
    {

        $response = array();
        $response["status"] = false;
        $response["message"] = "";

        $user = User::where("email", $request->email)->first();

        if ($user != null) {

            $password_reset = PasswordReset::where("email", $user->email);
            if ($password_reset->count() > 0) {
                $password_reset = $password_reset->first();
            } else {
                $password_reset = new PasswordReset();
            }

            $password_reset->email = $user->email;
            $password_reset->token = base64_encode(date("d-m-Y H:i:s"));
            $password_reset->save();

            \Mail::send("mail.recover_password", ["user" => $user, "token" => $password_reset->token], function ($message) use ($user) {
                $message->to($user->email)->subject('Recuperación de contraseña');
            });

            $response["status"] = true;
            $response["message"] = "Te hemos enviado un correo electrónico con instrucciones para reestablecer tu contraseña.";
            $response["url"] = url("");

        } else {
            $response["status"] = false;
            $response["message"] = "El correo electrónico no se encuentra registrado, intentalo nuevamente.";
        }

        return response()->json($response);
    }


    public function change_password($token, Request $request)
    {

        $error = true;

        //Rectificamos que el token exista y que la fecha de creacion no sea mayor a 30 minutos
        $password_reset = PasswordReset::where("token", $request->token)->first();

        if ($password_reset != null) {

            $password_reset_time = Carbon::createFromFormat("Y-m-d H:i:s", $password_reset->updated_at);
            $now = Carbon::now();
            if ($now->diffInMinutes($password_reset_time) < 30) {
                $error = false;
            } else {
                $error = true;
            }

        } else {
            $error = true;
        }


        return view('back.account.recovery', ["token" => $token, "error" => $error]);
    }


    public function update_password($token, Request $request)
    {

        $response = array();
        $response["error"] = true;
        $response["message"] = "";

        $password_reset = PasswordReset::where("token", $request->token)->first();
        if ($password_reset != null) {

            if ($request->password != $request->password_confirmed) {
                $response["error"] = true;
                $response["message"] = "El campo contraseña y confirmar contraseña no coinciden.";
            } else {

                $users = User::where("email", $password_reset->email)->first();

                if ($users != null) {

                    $users->password = bcrypt($request->password);
                    $users->save();

                    PasswordReset::where("token", $request->token)->delete();

                    $response["error"] = false;
                    $response["message"] = "La contraseña se ha restablecido correctamente.";
                    $response["url"] = url("/");
                } else {
                    $response["error"] = true;
                    $response["message"] = "No hemos podido restablecer tu contraseña, solicita la recuperación de contraseña nuevamente.";
                }

            }

        } else {
            $response["error"] = true;
            $response["message"] = "No hemos podido restablecer tu contraseña, solicita la recuperación de contraseña nuevamente.";
        }

        return response()->json($response);
    }

    public function test(){
        $url = "https://detente.app/";
        $institucion_name = "UANL";
        $email = "pizanho18@gmail.com";
        $id = "abc123";
        \Mail::send("mail.test", [], function ($message) use ($email) {
            $message->to($email)->subject('Reporte');
        });

        $subject = "";
        $message = "";

        // Mail::to('miguel.hernandez@metodika.mx')->send( "<h1>Ejemplo</h1>" );
        
        return "ok";
    }


}











