<?php

namespace MetodikaTI\Http\Controllers\Back\Dashboard;

use Illuminate\Http\Request;
use MetodikaTI\Http\Controllers\Controller;
use MetodikaTI\Institution;
use MetodikaTI\Estados;
use MetodikaTI\Municipios;
use MetodikaTI\User;
use MetodikaTI\Preguntas;
use MetodikaTI\Codigos;
use MetodikaTI\UsersApp;
use MetodikaTI\Notas;
use MetodikaTI\Chats;
use MetodikaTI\Comunicados;
use MetodikaTI\ComunicadosCodigos;
use MetodikaTI\Horarios;
use MetodikaTI\Vacaciones;
use MetodikaTI\Telefonos;
use MetodikaTI\UserProfile;
use MetodikaTI\Incidentes;
use MetodikaTI\Library\URI;

class InstitucionesController extends Controller
{
    public function index(){
        $data = Institution::get();
        $data_users = [];

        foreach ($data as $key => $value) {
            $codigos = Codigos::where("id_institucion", $value->id)->pluck("id")->toArray();
            $users = UsersApp::whereIn("id_codigo", $codigos)->count();
            array_push( $data_users, array( 
                                            "id"   => $value->id,                                             
                                            "name" => $value->name, 
                                            "created_at" => $value->created_at, 
                                            "estatus"    => $value->estatus, 
                                            "num_users"  => $users 
                                        ));
            error_log( "Institucion =>" . print_r( $users,true) );
        }

        return view('back.instituciones.index', array( "data_institucion" =>  $data_users, "data" => $data, 'permitions' => URI::checkPermitions() ));
    }

    public function create(){
        return view('back.instituciones.create', array());
    }

    public function estados( Request $request ){
        $estados = Estados::get();        
        $response["estados"] = $estados;        
        
        return response()->json($response, 200);
    }

    public function municipios( Request $request ){
        $municipios = Municipios::where("estado",$request->clave_estado)->get();
        $response["municipios"] = $municipios;
        return response()->json($response, 200);
    }

    public function insert_estados( Request $request ){

        
        $data = Municipios::get();        
        
        foreach ($request->data as $key => $value) {
            
            // $muni = new Municipios();

            // $muni->estado = 32;
            // $muni->clave = $value["clave"];
            // $muni->nombre = $value["nombre"];

            // $muni->save();
            # code...
            // error_log( $value["clave"] );
        }

        $response["data"] = $data;

        return response()->json($response, 200);

    }

    public function create_institucion( Request $request ){
    
        $response["status"] = false;
        
        $this->validate(
            $request, 
            [   
                'nombre'    => 'required',
                'contacto_informativo'    => 'required',
                'telefono'  => 'required|min:10|numeric',
                'direccion' => 'required',
                'pass'      => 'required',
                'email_master' => 'required|email',
                'confirm_pass' => 'required', 
                'estatus'   => 'required',
                'estado'    => 'required',
                'municipio' => 'required'                              
            ],
            [   
                'nombre.required'    => 'El campo Nombre es obligatorio',
                'contacto_informativo.required'    => 'El nombre del Contacto Informativo obligatorio',                
                'telefono.required'  => 'El campo Teléfono es obligatorio',
                'telefono.min'       => 'El campo Teléfono debe contener al menos 10 caracteres',
                'telefono.numeric'   => 'El campo Teléfono debe contener solo numeros',
                'direccion.required' => 'El campo Dirección es obligatorio',
                'email_master.required' => 'El campo Correo es obligatorio',
                'email_master.email'    => 'El formato de Correo Electrónico es incorrecto.',
                'pass.required'         => 'El campo Contraseña es obligatorio.',
                'confirm_pass.required' => 'El campo Confirmar Contraseña es obligatorio',
                'municipio.required'    => 'El campo Municipio es obligatorio',
                'estado.required'    => 'El campo Estado es obligatorio',
                'estatus.required'   => 'El campo Estatus es obligatorio'            
            ]
        );


        if( $request->pass != $request->confirm_pass ){
            $response["message"] = "Las contraseñas no son iguales."; 
            return response()->json($response, 200);
        }

        
        //PRIMERO SE CREA EL USUARIO       

        $institucion = new Institution();

        $institucion->name      = $request->nombre;
        $institucion->phone     = $request->telefono;
        $institucion->direction = $request->direccion;
        $institucion->contact   = $request->contacto_informativo;
        $institucion->email_contact = $request->email_contacto_info;   
        $institucion->estatus   = $request->estatus;   
        $institucion->state     = $request->estado;  
        $institucion->city      = $request->municipio;   
        $institucion->sector    = $request->sector;   
        
        $user_q = User::where("email", $request->email_master)->first();

        if( $user_q ){
            $response["message"] = "El usuario ya existe en la base de datos."; 
            return response()->json($response, 200);
        }


        if($request->hasFile("logo")){
            $file_name = md5(date("Y-m-d H:i:s")).".".$request->file('logo')->getClientOriginalExtension();
            $request->file('logo')->move("assets/images/logos/", $file_name );

            if( file_exists($institucion->logo) ){
                unlink($institucion->logo);
            }

            $institucion->logo= "assets/images/logos/".$file_name;
        }


        if( $institucion->save() ){

            $url_b = url("/assets/images/calificacion/10-s.png");
            $email_master = $request->email_master;
            // \Mail::send("mail.bienvenida", ["url" => $url_b, "nombre_institucion" => $request->nombre ], function ($message) use ($email_master) {
            //     $message->to($email_master)->subject('¡Bienvenido!');
            // });
            
            $user = new User();

            $user->name     = $request->nombre_master;
            $user->lastname = $request->apellidos_master === null ? "" : $request->apellidos_master;
            $user->email    = $request->email_master;
            $user->password = bcrypt($request->pass);
            $user->phone    = $request->telefono_master === null ? "": $request->telefono_master;
            $user->puesto   = $request->puesto === null ? "" : $request->puesto ;
            $user->id_institucion  =  $institucion->id;
            $user->user_profile_id =  3;

            $user->save();                        

            $url = url("/assets/images/emails/candado.png");

            // \Mail::send("mail.master", ["url" => $url, "nombre_institucion" => $request->nombre, "usuario" => $request->email_master, "pw" => $request->pass ], function ($message) use ($user) {
            //     $message->to($user->email)->subject('!Bienvenido!');
            // });

            //se añaden las preguntas para no generar error al momento de reportar
           
            for( $contador = 1; $contador <= 2; $contador = $contador + 1 ){

                $preg = new Preguntas();
                $preg->id_institucion = $institucion->id;
                $preg->save();

            }

            $response["reload"] = true;
            $response["url"] = route("instituciones");
            $response["status"]  = true;
            $response["message"] = "Los datos se guardaron correctamente."; 

        }else{            
            $response["message"] = "¡Uy! Algo salió mal."; 
        }                                 
        
        return response()->json($response, 200);
        
    }

    public function update_institucion( Request $request, $id ){

        $response["status"] = false;

        $this->validate(
            $request, 
            [   
                'nombre'   => 'required',
                'telefono' => 'required',
                'direccion' => 'required',                               
                'estatus' => 'required',
                'estado' => 'required',
                'municipio' => 'required',
                'email_contacto_info' => 'email'                              
            ],
            [   
                'nombre.required'    => 'El campo Nombre es obligatorio',                
                'telefono.required'  => 'El campo Teléfono es obligatorio',
                'direccion.required' => 'El campo Dirección es obligatorio', 
                'email_contacto_info.email' => "El formato de correo electrónico es incorrecto."                           
            ]
        );


        $institucion = Institution::find(base64_decode($id));

        if($request->hasFile("logo")){
            $file_name = md5(date("Y-m-d H:i:s")).".".$request->file('logo')->getClientOriginalExtension();
            $request->file('logo')->move("assets/images/logos/", $file_name );

            if( file_exists($institucion->logo) ){
                unlink($institucion->logo);
            }

            $institucion->logo= "assets/images/logos/".$file_name;
        }
        
        $institucion->name      = $request->nombre;
        $institucion->phone     = $request->telefono;
        $institucion->direction = $request->direccion;
        $institucion->contact   = $request->contacto_informativo;
        $institucion->email_contact = $request->email_contacto_info;   
        $institucion->estatus   = $request->estatus;   
        $institucion->state     = $request->estado;  
        $institucion->city      = $request->municipio;   
        $institucion->sector    = $request->sector;  

        if( $institucion->save() ){
            $response["reload"] = true;
            // $response["url"] = env("APP_URL")."/dashboard/instituciones/editar-institucion/".$id;
            $response["url"] = $id;
            $response["status"]  = true;
            $response["message"] = "Los datos se guardaron correctamente."; 
        }

        return response()->json($response, 200);
        
    }

    public function editar_institucion( Request $request, $id ){

        $institucion = Institution::find(base64_decode($id));
        $estados     = Estados::get();

        return view('back.instituciones.editar_institucion', array( "institucion" => $institucion, "estados" => $estados ));
    }

    public function delete_institucion( $id ){        

        $response["status"] = false;            

        $del = Institution::where("id",base64_decode($id))->delete();

        if( $del ){
            
            User::where("id_institucion", base64_decode($id))->delete();

            $ids_incidentes = Incidentes::where("id_institucion", base64_decode($id))->pluck("id")->toArray();
        
            Notas::whereIn("id_incidente", $ids_incidentes)->delete();
            Chats::whereIn("id_incidente", $ids_incidentes)->delete();
            
            Incidentes::where("id_institucion",base64_decode($id))->delete();        
            Comunicados::where("id_institucion",base64_decode($id))->delete();
    
            $codigos = Codigos::where("id_institucion", base64_decode($id))->pluck("id")->toArray();
            ComunicadosCodigos::whereIn("id_codigo", $codigos)->delete();
        
            Horarios::where("id_institucion", base64_decode($id))->delete();
            Vacaciones::where("id_institucion", base64_decode($id))->delete();
            Preguntas::where("id_institucion", base64_decode($id))->delete();
            Telefonos::where("id_institucion", base64_decode($id))->delete();
            
            UsersApp::whereIn("id_codigo", $codigos)->delete();
            UserProfile::where("id_institucion", base64_decode($id))->delete();

            Codigos::where("id_institucion", base64_decode($id))->delete();


            $response["reload"] = true;            
            $response["url"] = route('instituciones');
            $response["status"] = true;
            $response["message"] = "La institución se eliminó correctamente";

        }else{
            $response["message"] = "¡Uy! Algo salió mal al querer eliminar la institución"; 
        }


        return response()->json($response, 200);
    }

    public function activar_institucion( Request $request ){        
                
        $response["status"] = false;

        $institucion = Institution::find($request->id);
        
        $institucion->estatus = $request->status;

        if($institucion->save()){
            $response["status"] = true;
            if($request->status==0){
                $response["message"] = "La institución se desactivo correctamente";
            }else{
                $response["message"] = "La institución se activo correctamente";
            }
        }

        return response()->json($response, 200);
    }

    public function desactivar_institucion( $id ){
        $response["status"] = false;

        $institucion = Institution::find(base64_decode($id));

        $institucion->estatus = 0;

        if($institucion->save()){
            $response["reload"] = true;
            $response["status"] = true;
            $response["message"] = "La institución se desactivo correctamente."; 
        }

        return response()->json($response, 200);
    }

}


