<?php

namespace MetodikaTI\Http\Controllers\Back\Dashboard;

use Illuminate\Http\Request;
use MetodikaTI\Http\Controllers\Controller;
use MetodikaTI\Telefonos;
use MetodikaTI\Library\URI;
use Auth;

class TelefonosController extends Controller
{
    public function index(){
        $user = Auth::user();  
        $data = Telefonos::where("id_institucion", $user->id)->get();
        return view('back.telefonos.index', array( "data" => $data, 'permitions' => URI::checkPermitions() ));
    }

    public function index_tel(){
        $user = Auth::user();  
        $data = Telefonos::where("id_institucion", $user->id_institucion)->orderBy("orden", "ASC")->get();
        return view('back.telefonos.index_tel', array( "data" => $data, 'permitions' => URI::checkPermitions() ));
    }

    public function nuevo_telefono(){
        return view('back.telefonos.create', array( 'permitions' => URI::checkPermitions() ));
    }

    public function save_telefono( Request $request ){                

        $response["status"] = false;

        $this->validate(
            $request, 
            [   
                'contacto' => 'required',
                'telefono' => 'required|numeric',                                          
            ],
            [   
                'contacto.required' => 'El campo contacto es requerido',
                'telefono.required' => 'El campo teléfono es requerido', 
                'telefono.numeric'  => 'Ingresa solo números en el campo teléfono.',                                     
            ]
        );

        $user = Auth::user();        
        $telefono = new Telefonos();

        $telefono->name     = $request->contacto;
        $telefono->telefono = $request->telefono;
        $telefono->id_institucion = $user->id_institucion;

        if( $telefono->save() ){
            $response["status"] = true;
            $response["reload"] = true;
            $response["url"] = route("telefonos");
            $response["message"] = "El teléfono se guardó correctamente.";
        }else{
            $response["status"] = false;
            $response["reload"] = false;
            $response["url"] = "nuevo-telefono";
            $response["message"] = "¡Uy! Algo salió mal. No se pudo guardar el teléfono.";
        }
        
        return response()->json($response, 200);
    }

    public function editar_telefono( $id ){

        $telefono = Telefonos::find( base64_decode( $id ) );
        return view('back.telefonos.editar', array( "telefono" => $telefono, 'permitions' => URI::checkPermitions() ));
    }

    public function delete_telefono( $id ){

        $response["status"] = false;

        if( $id ){
            $telefono = Telefonos::where("id", base64_decode( $id ) )->delete();

            if( $telefono ){
                $response["status"] = true;
                $response["url"] = route('telefonos');
                $response["message"] = "El teléfono se elimino correctamente";
            }else{
                $response["status"] = false;
                $response["message"] = "¡Uy! Algo salió mal. No se encontró el teléfono.";
            }


        }else{
            $response["message"] = "¡Uy! Algo salió mal. No se pudo eliminar el teléfono.";
        }

        return response()->json($response, 200);

    }

    public function update_telefono( Request $request, $id ){

        $response["status"] = false;

        $this->validate(
            $request, 
            [   
                'contacto' => 'required',
                'telefono' => 'required|numeric',                                          
            ],
            [   
                'contacto.required' => 'El campo contacto es requerido',
                'telefono.required' => 'El campo teléfono es requerido', 
                'telefono.numeric'  => 'Ingresa solo numeros en el campo teléfono.',                                     
            ]
        );

        $telefono           = Telefonos::find(base64_decode($id));
        $telefono->name     = $request->contacto;
        $telefono->telefono = $request->telefono;

        if( $telefono->save() ){
            $response["reload"] = true;            
            $response["url"] = route('telefonos');//$id;
            $response["status"]  = true;
            $response["message"] = "Los datos se actualizaron correctamente."; 
        }else{
            $response["status"]  = false;
            $response["message"] = "¡Uy! Algo salió mal. No se pudo actualizar el teléfono.";
        }

        return response()->json($response, 200);

    }

    public function update_telefono_new( Request $request ){

        $response["status"] = false;

        $this->validate(
            $request, 
            [   
                'id'       => 'required',
                'name' => 'required',
                'telefono' => 'required|numeric',                                          
            ],
            [   
                'name.required' => 'El campo contacto es requerido',
                'telefono.required' => 'El campo teléfono es requerido', 
                'telefono.numeric'  => 'Ingresa solo números en el campo teléfono.',                                     
            ]
        );

        $telefono           = Telefonos::find($request->id);
        $telefono->name     = $request->name;
        $telefono->telefono = $request->telefono;  
        
        if( $telefono->save() ){
            $response["reload"] = true;            
            $response["url"] = route('telefonos');//$id;
            $response["status"]  = true;
            $response["message"] = "Los datos se actualizaron correctamente."; 
        }else{
            $response["status"]  = false;
            $response["message"] = "¡Uy! Algo salió mal. No se pudo actualizar el teléfono.";
        }

        return response()->json($response, 200);

    }   

    public function eliminar_telefono_new( Request $request ){

        $response["status"] = false;

        $this->validate(
            $request, 
            [   
                'id' => 'required',                                                    
            ],
            [   
                'id.required' => 'No se pudo eliminar el teléfono',                                                   
            ]
        );

        if( $request->id ){
            $telefono = Telefonos::where("id",  $request->id )->delete();

            if( $telefono ){
                $response["status"] = true;
                // $response["url"] = route('telefonos');
                $response["message"] = "El teléfono se eliminó correctamente";
            }else{
                $response["status"] = false;
                $response["message"] = "¡Uy! Algo salió mal. No se encontró el teléfono.";
            }


        }else{
            $response["message"] = "¡Uy! Algo salió mal. No se pudo eliminar el teléfono.";
        }

        return response()->json($response, 200);

    }

    public function update_orden_telefono( Request $request ){

        $response["status"] = false;

        $user = Auth::user(); 

        if( count( $request->orden ) > 0 ){
            $response["data"] = $user;
            
            foreach ($request->orden as $key => $value) {       
                Telefonos::where( "id", $value["id"] )->update(["orden" => $value["orden"]]);
            }

            $response["status"] = true;                
            $response["message"] = "El orden de los teléfonos se actualizó correctamente.";

        }else{
            $response["message"] = "¡Uy! Algo salió mal. No se pudo eliminar el teléfono.";
        }

        return response()->json($response, 200);
        
    }
    
}
